%% Choix des cartes à échanger.
% Cette fonction prend le 5-vecteur "main" décrivant les hauteurs dans la
% main du joueur, et renvoie le 5-vecteur "choix" de booléens décrivant,
% pour chaque carte correspondante de la main, si le joueur choisit ou non
% d'échanger cette carte.
function choix = decision (main)
% "Nmain" désigne le nombre de cartes dans une main, soit 5.
Nmain = 5;
% Nous allons compter, pour chaque carte de la main (indexée par "i"),
% combien de cartes de même hauteur (grâce à une boucle indexée par "j")
% apparaissant dans la main. Le résultat sera stocké dans un 5-vecteur
% "comptage", dont la i-ième case correspondra au total trouvé pour la
% carte en i-ième position de la main.
comptage = zeros (1, Nmain);
for i = 1 : Nmain
    for j = 1 : Nmain
        if main (i) == main (j)
            comptage (i) = comptage (i) + 1;
        end
    end
end
% On va regarder quelle hauteur apparait le plus souvent dans notre main.
% Pour cela on va maintenir une variable "record" disant le plus grand
% nombre d'occurrences qu'on ait vu jusque-là, et une variable "recordman"
% disant quelle hauteur détient ce record ; et on va parcourir notre main
% par un indice "i" pour chercher si ce record est battu.
record = 0;
recordman = 0;
for i = 1 : Nmain
    if comptage (i) > record
        record = comptage (i);
        recordman = main (i);
    end
end
% Il va maintenant falloir choisir les cartes qu'on échange. On commence
% par initialiser "choix" à « aucun changement ».
choix = false (1, Nmain);
% En fonction de la valeur de "record", on décide comment on change nos
% cartes. Si "record" vaut au moins 3, on ne change rien. Si "record" vaut
% 2, on change toutes les cartes qui ne sont pas de la hauteur recordman.
% Si "record" vaut 1, on décide arbitrairement de changer les trois
% premières.
if record >= 3
elseif record == 2
    for i = 1 : Nmain
        choix (i) = (main (i) ~= recordman);
    end
else
    for i = 1 : Nmain
        choix (i) = (i <= 3);
    end
end
return
end