%% Simulation d'un sabot mélangé de 52 cartes.
% Cette fonction renvoie un 52-vecteur aléatoire "s" contenant une unique
% fois chaque entier entre 0 et 51, s étant tiré uniformément parmi toutes
% les possibilités.
function s = sabot ()
% "Ncartes" est un nom de variable pour éviter de saisir « 52 » plusieurs
% fois.
Ncartes = 52;
% On initialise "s", tant qu'à faire avec que des -1 pour éviter la
% confusion avec la carte numéro 0.
s = -1 * ones (1, Ncartes);
% On va suivre une procédure consistant composer notre sabot carte par
% carte, en sélectionnant à chaque fois une carte uniformément parmi toutes
% celles qui n'ont pas encore été tirées. Pour cela on a besoin d'un
% vecteur (de taille variable) "cartes_non_tirees" listant ces cartes
% restantes, qu'on initialise à la liste de toutes les cartes.
cartes_non_tirees = 0 : Ncartes - 1;
% Il y a 52 itérations à faire, indexées par "i".
for i = 1 : Ncartes
    % "j" est la position de la prochaine carte tirée parmi les cartes non
    % encore tirées ; c'est donc un entier uniforme entre 1 et (53-i).
    j = ceil ((Ncartes + 1 - i) * rand ());
    % On regarde l'identité correspondant à la j-ième carte de
    % "cartes_non_tirees" et on la reporte en i-ième position de "s".
    s (i) = cartes_non_tirees (j);
    % Il faut maintenant mettre à jour "cartes_non_tirees". Nous allons
    % pour cela créer un nouveau vecteur "nouveau_cnt", de taille
    % (Ncartes-i), que nous remplirons à partir de l'ancien
    % "cartes_non_tirees", avant d'écraser "cartes_non_tirees" avec.
    nouveau_cnt = -1 * ones (1, Ncartes - i);
    % On remplit "nouveau_cnt" à partir de "cartes_non_tirees" en deux
    % temps, selon qu'on est avant ou après la position j. "k" désigne la
    % position dans "cartes_non_tirees" qu'on est en train de reporter dans
    % "nouveau_cnt".
    for k = 1 : j - 1
        nouveau_cnt (k) = cartes_non_tirees (k);
    end
    % Après la position "j", la carte reportée dans "nouveau_cnt" y
    % apparait évidemment une position plus tôt qu'elle ne l'était dans
    % "cartes_non_tirées".
    for k = j + 1 : Ncartes + 1 - i
        nouveau_cnt (k - 1) = cartes_non_tirees (k);
    end
    % On remplace "cartes_non_tirees" par "nouveau_cnt".
    cartes_non_tirees = nouveau_cnt;
end
return
end