%% Détermination d'un estimateur essentiellement sans biais de \theta, avec intervalle de confiance.
% Cette fonction prend en entrée le nombre "N" de réalisations de
% l'expérience aléatoire considérée, la valeur "Xetoile" de X_* trouvée
% pour ces réalisations, et le nombre "Nsim" de simulations demandées par
% l'utilisateur pour la méthode de Monte-Carlo. Elle en déduit un
% estimateur essentiellement sans biais de \theta, ainsi qu'un intervalle
% de confiance à 90 % (avec un risque symétrique) pour celui-ci, qu'elle
% affiche.
function estimateur (N, Xetoile, Nsim)
% On va regarder les caractéristiques des fluctuations de (X_*-\theta)
% lorsque le paramère \theta est exactement égal à X_*, en faisant
% l'hypothèse que ce ne sera pas trop différent pour le vrai \theta.
[quantiles, moyenne] = fluctuations_compact (Xetoile, N, Nsim);
% On en déduit l'estimateur essentiellement sans biais de \ŧheta, noté
% "estimateur".
estimateur = Xetoile - moyenne;
% On en déduit aussi l'intervalle de confiance pour l'estimateur, noté
% "IC". — Attention, comme il y a un signe ‘-’ qui intervient, le quantile
% à 5 % des fluctuations donne un quantile à 95 % pour l'estimateur, et
% vice-versa.
IC = zeros (1, 2);
IC (1) = Xetoile - quantiles (2);
IC (2) = Xetoile - quantiles (1);
% On affiche les résultats.
fprintf ('L''estimateur (essentiellement) sans biais de \\theta vaut ');
fprintf ('%f.\n', estimateur);
fprintf ('Avec un risque de 5 %% de chaque côté, ');
fprintf ('\\theta est compris entre %f et %f.\n', IC (1), IC (2));
return
end