%% Histogramme des fluctuations de (X_*-\theta).
% Cette fonction prend trois entrées : le paramètre "theta" et le nombre de
% simulations "N" de l'expérience statistique qu'on est en train de
% considérer, et le nombre "Nsim" de simulations à utiliser pour la méthode
% de Monte-Carlo. Elle affiche (une estimation de) l'histogramme de la loi
% de (X_*-\theta).
function fluctuations (theta, N, Nsim)
% Le vecteur "simulations" est destiné à trouver les valeurs simulées pour
% la différence (X_*-\theta).
simulations = zeros (1, Nsim);
for i = 1 : Nsim
    % "Xetoile" sera la valeur de X_*. Nous l'initialisons à une valeur
    % dont nous savons qu'elle sera forcément dépassée.
    Xetoile = 0;
    for j = 1 : N
        % "Xj" est la j-ième valeur de notre expérience aléatoire.
        Xj = theta * rand ();
        % On met à jour "Xetoile".
        if Xj > Xetoile
            Xetoile = Xj;
        end
    end
    % On stocke la valeur de (X_*-\theta) obtenue lors de cette simulation.
    simulations (i) = Xetoile - theta;
end
% "histogram" est une fonction de haut niveau de Matlab permettant de
% tracer l'histogramme d'une série de données, avec un choix automatique
% des paramètres.
histogram (simulations);
return
end