% Méthode de Monte-Carlo naïve pour le calcul de E(f).
% Cette fonction prend en argument le nombre "Nsim" de simulations demandées, et
% affiche la valeur estimée de E(f) ainsi que son intervalle de confiance à 95
% %.
function PF60_naif (Nsim)
% "total_f" et "total_f2" seront les sommes respectives des valeurs simulées de
% resp. f et f^2.
total_f = 0;
total_f2 = 0;
% Début de la boucle de Monte-Carlo, indexée par "i".
for i = 1 : Nsim
  % On procède à la simulation d'une série de lancers. Noter que pour /chaque/
  % simulation il y a 100 lancers à effectuer, et donc une boucle, indexée par
  % "j". Le nombre de « pile » obtenus est stocké dans "X".
  X = 0;
  for j = 1 : 100
    if rand () < 1 / 2
      X = X + 1;
    end
  end
  % On calcule la valeur "f" de f pour cette simulation, et on met à jour les
  % totaux.
  exces = X - 60;
  if exces > 0
    f = exces;
  else
    f = 0;
  end
  total_f = total_f + f;
  total_f2 = total_f2 + f * f;
end
% Maintenant on calcule les grandeurs essentielles de la méthode de Monte-Carlo,
% avec des noms de variables transparents.
moyenne_f = total_f / Nsim;
variance_f = total_f2 / Nsim - moyenne_f * moyenne_f;
variance_estimateur = variance_f / Nsim;
% On affiche le résultat.
fprintf ('E(f) est estimée à %f ± %f.\n', ...
  moyenne_f, 1.96 * sqrt (variance_estimateur));
return
end