% Méthode de Monte-Carlo avec échantillonnage préférentiel pour le calcul de E(f).
% Cette fonction prend en argument le nombre "Nsim" de simulations demandées, et
% affiche la valeur estimée de E(f) ainsi que son intervalle de confiance à 95
% %. Je ne commente que les différences avec "PF60_naif".
function PF60_pref (Nsim)
% J'appelle "pipage" la probabilité de tomber sur « pile » pour la probabilité
% pipée que nous avons choisie.
pipage = .60;
% Il serait malvenu d'appeler encore la variable à intégrer « f », vu que ce
% n'est plus la même ; je l'appellerai donc « g ».
total_g = 0;
total_g2 = 0;
for i = 1 : Nsim
  % En plus de la valeur simulée en elle-même, nous allons avoir besoin de
  % calculer la densité "densite" de l'ancienne loi par rapport à la nouvelle
  % pour la simulation réalisée. Nous obtiendrons cette densité comme un
  % produit, évalué au fur et à mesure de la simulation.
  densite = 1;
  X = 0;
  for j = 1 : 100
    % Maintenant notre série de lancers est faite avec une pièce /pipée/ !
    if rand () < pipage
      X = X + 1;
      % Il faut aussi mettre à jour la densité…
      densite = densite * (1 / 2) / pipage;
    else
      % Attention : quand on tombe sur « face », "X" ne change pas, mais
      % "densite" si…!
      densite = densite * (1 / 2) / (1 - pipage);
    end
  end
  exces = X - 60;
  if exces > 0
    f = exces;
  else
    f = 0;
  end
  % La variable "g" dont nous calculons l'espérance sous la loi pipée est le
  % produit de f par la densité.
  g = f * densite;
  total_g = total_g + g;
  total_g2 = total_g2 + g * g;
end
moyenne_g = total_g / Nsim;
variance_g = total_g2 / Nsim - moyenne_g * moyenne_g;
variance_estimateur = variance_g / Nsim;
% En termes d'affichage du résultat, c'est toujours l'espérance de f sous la loi
% non pipée qu'on cherchait à calculer…!
fprintf ('E(f) est estimée à %f ± %f.\n', ...
  moyenne_g, 1.96 * sqrt (variance_estimateur));
return
end