% Estimation de p_0 par la méthode de Monte-Carlo.
% "Nsim" est le nombre de simulations demandées.
function grecque_base (Nsim)
% Paramètres généraux, avec des noms de variables transparents.
Njours = 5;
seuil = 2;
esp_increment = -.2;
var_increment = 1.;
% Début de l'algorithme de Monte-Carlo.
succes = 0;
for i = 1 : Nsim
  % "cours(j)" sera la valeur du cours de l'actif au jour "j"; on commence par
  % allouer la mémoire pour ces données.
  cours = zeros (Njours, 1);
  % "actif" est la valeur courante de l'actif, initialisée au jours 0.
  actif = 0;
  % Évolution de l'actif.
  for j = 1 : Njours
    increment = esp_increment + sqrt (var_increment) * randn ();
    actif = actif + increment;
    cours(j) = actif;
  end
  % Il faut tester si le cours a dépassé la valeur seuil, ce que nous dira
  % "test".
  test = false;
  for j = 1 : Njours
    test = test || (cours(j) > seuil);
  end
  % On met à jour le nombre de succès.
  if test
    succes = succes + 1;
  end
end
% La fin du code est classique...
p0_empirique = succes / Nsim;
var_fonction = p0_empirique - p0_empirique * p0_empirique;
var_estimateur = var_fonction / Nsim;
fprintf ('p_0 vaut %f %% ± %f.\n', ...
  100 * p0_empirique, 100 * 1.96 * sqrt (var_estimateur));
return
end