% Estimation de p_1-p_0 par la méthode de Monte-Carlo avec technique de couplage.
% "Nsim" est le nombre de simulations demandées. Je ne commente que les aspects
% relevant du couplage.
function grecque_coupl (Nsim)
% Comme on a deux phénomènes à simuler, certains paramètres sont dédoublés.
Njours = 5;
esp_incr_0 = -.2;
esp_incr_1 = -.18;
var_incr_0 = 1.;
var_incr_1 = 1.1;
seuil = 2;
% Notez qu'on n'est plus en train d'évaluer l'espérance d'une simple
% indicatrice; il faut donc compter séparément total et total des carrés (avec
% des noms de variables transparents).
total_f = 0;
total_f2 = 0;
% Chaque passage dans la boucle de Monte-Carlo correspond à une simulation
% /couplée/ du /double/ phénomène aléatoire.
for i = 1: Nsim
  % Comme il y a maintenant deux façons différentes d'utiliser l'aléa, il y a
  % maintenant "cours_0" et "cours_1", etc.
  cours_0 = zeros (Njours);
  cours_1 = zeros (Njours);
  actif_0 = 0;
  actif_1 = 0;
  for j = 1: Njours
    % Ici réside le cœur du couplage : on utilise la /même/ source aléatoire
    % "alea" (en l'occurrence une loi normale standard) pour simuler les lois
    % pourtant /différentes/ des deux incréments !
    alea = randn ();
    increment_0 = esp_incr_0 + sqrt (var_incr_0) * alea;
    increment_1 = esp_incr_1 + sqrt (var_incr_1) * alea;
    actif_0 = actif_0 + increment_0;
    actif_1 = actif_1 + increment_1;
    cours_0(j) = actif_0;
    cours_1(j) = actif_1;
  end
  test_0 = false;
  test_1 = false;
  for j = 1: Njours
    test_0 = test_0 || (cours_0 (j) > seuil);
    test_1 = test_1 || (cours_1 (j) > seuil);
  end
  % La fonction d'intérêt "f" est la différence entre les indicatrices du succès
  % dans le cas 1 et du succès dans le cas 0.
  f = 0;
  if test_1
    f = f + 1;
  end
  if test_0
    f = f - 1;
  end
  % Notre méthode de Monte-Carlo porte maintenant sur la fonction d'intérêt f,
  % c'est donc simplement en fonction d'elle qu'on doit procéder.
  total_f = total_f + f;
  total_f2 = total_f2 + f * f;
end
moy_f = total_f / Nsim;
moy_f2 = total_f2 / Nsim;
var_f = moy_f2 - moy_f * moy_f;
var_estimateur = var_f / Nsim;
fprintf ('p_1 - p_0 vaut %f %% ± %f.\n', ...
  100 * moy_f, 100 * 1.96 * sqrt (var_estimateur));
return
end