% La fonction "grecque_noncoupl" évalue la différence p_1-p_0 de façon naïve, en se contentant de mettre bout à bout les calculs pour p_0 et pour p_1.
% "Nsim_0" et "Nsim_1" sont les nombre de simulations demandées resp. pour
% l'évaluation de p_0 et de p_1.
function grecque_noncoupl (Nsim_0, Nsim_1)
Njours = 5;
seuil = 2;
esp_incr_0 = -.2;
esp_incr_1 = -.18;
var_incr_0 = 1.;
var_incr_1 = 1.1;
% Estimation de p_0.
succes = 0;
for i = 1 : Nsim_0
  cours = zeros (Njours, 1);
  actif = 0;
  for j = 1 : Njours
    increment = esp_incr_0 + sqrt (var_incr_0) * randn ();
    actif = actif + increment;
    cours(j) = actif;
  end
  test = false;
  for j = 1: Njours
    test = test || (cours(j) > seuil);
  end
  if test
    succes = succes + 1;
  end
end
p_0 = succes / Nsim_0;
var_f_0 = p_0 - p_0 * p_0;
% On se contente de calculer la variance de l'estimateur de p_0 ; pour
% l'instant, on n'affiche rien…
var_estr_0 = var_f_0 / Nsim_0;
% Estimation de p_1.
succes = 0;
for i = 1: Nsim_1
  cours = zeros (Njours);
  actif = 0;
  for j = 1: Njours
    increment = esp_incr_1 + sqrt (var_incr_1) * randn ();
    actif = actif + increment;
    cours(j) = actif;
  end
  test = false;
  for j = 1: Njours
    test = test || (cours(j) > seuil);
  end
  if test
    succes = succes + 1;
  end
end
% On calcule l'estimateur de p_1 ainsi que la variance associée.
p_1 = succes / Nsim_1;
var_f_1 = p_1 - p_1 * p_1;
var_estr_1 = var_f_1 / Nsim_1;
% On calcule maintenant l'estimateur global, et sa variance ; et on affiche le
% résultat.
diff_p = p_1 - p_0;
% Comme les deux estimations sont indépendantes, il faut ajouter les variances
% pour avoir la variance de la différence.
var_estr = var_estr_1 + var_estr_0;
fprintf ('p_1 - p_0 vaut %f %% ± %f.\n', ...
  100 * diff_p, 100 * 1.96 * sqrt (var_estr));
return
end
