% Estimation de la probabilité de défaut avec échantillonnage préférentiel.
% Cette fonction prend en entrée le nombre "Nsim" de simulations demandées, et
% affiche l'estimation de la probabilité de défaut, assortie de son intervalle
% de confiance à 95 %. Je ne commente que les différences avec "defaut_simple".
function defaut_pref (Nsim)
% Il faut aussiprendre en compte "muAech" et "muBech" dans les variables
% externes.
global Sperso Sinvest Sbanque r piA piB muA muB sigmaAA sigmaBB sigmaAB ...
  muAech muBech
init_17bis ();
XA = piA * Sinvest;
XB = piB * Sinvest;
% On calcule une fois pour toutes la matrice "gradlogdens" =
% (mu_A-mu_A^ech,mu_B-mu_B^ech)*SIMGA^(-1), où "SIGMA" est la matrice de
% covariance "SIGMA" qui apparait dans notre modèle, car nous en aurons beaucoup
% besoin dans les calculs.
SIGMA = [sigmaAA sigmaAB; sigmaAB sigmaBB];
gradlogdens = ([muA, muB] - [muAech, muBech]) / SIGMA;
R = (chol (SIGMA))';
% Cette fois ci la quantité dont on regarde l'espérance empirique n'est plus une
% indicatrice.
somme_f = 0;
somme_f2 = 0;
for i = 1 : Nsim
  % Cette fois-ci "accrlog" doit être simulé sous la loi d'échantillonnage
  % préférentiel.
  accrlog = [muAech; muBech] + R * randn (2, 1);
  % Il faut aussi calculer la densité "densite" de l'ancienne probabilité par
  % rapport à la nouvelle.
  densite = exp (gradlogdens * (accrlog - ([muA; muB] + [muAech; muBech]) / 2));
  factaccr = exp (accrlog);
  Xp = [XA; XB] .* factaccr;
  XAp = Xp(1);
  XBp = Xp(2);
  % La variable aléatoire "f" dont on considère l'espérance ici est
  % l'indicatrice du défaut /multipliée par la densité/.
  if XAp + XBp - Sinvest + Sperso < r * Sbanque
    f = densite;
  else
    f = 0;
  end
  somme_f = somme_f + f;
  somme_f2 = somme_f2 + f * f;
end
% La fin du code est maintenant classique…
moy_f = somme_f / Nsim;
var_f = somme_f2 / Nsim - moy_f * moy_f;
var_estr = var_f / Nsim;
fprintf ('Probabilité de défaut : %f %% ± %f.\n', ...
  100 * moy_f, 100 * 1.96 * sqrt (var_estr));
return
end
