% Estimation naïve de la probabilité de défaut.
% Cette fonction prend en entrée le nombre "Nsim" de simulations demandées, et
% affiche l'estimation de la probabilité de défaut, assortie de son intervalle
% de confiance à 95 %.
function defaut_simple (Nsim)
% Initialisation des paramètres à l'aide de la fonction "init_17bis". Bien
% penser à déclarer les variables concernées comme globales…
global Sperso Sinvest Sbanque r piA piB muA muB sigmaAA sigmaBB sigmaAB
init_17bis ();
% Montants investis resp. dans les actions A et B.
XA = piA * Sinvest;
XB = piB * Sinvest;
% On calcule une fois pour toutes la matrice qui nous servira à simuler le
% vecteur gaussien de notre modèle.
R = (chol ([sigmaAA sigmaAB; sigmaAB sigmaBB]))';
% "defauts" compte le nombre de simulations où on observe un défaut.
defauts = 0;
for i = 1 : Nsim
  % "accrlog" est le 2-vecteur (colonne) gaussien qui décrit l'accroissement
  % logarithmique des valeurs des placements dans les entreprises respectives A
  % et B.
  accrlog = [muA; muB] + R * randn (2, 1);
  % "factaccr" est le vecteur des facteurs d'accroissement, càd. l'exponentielle
  % case-à-case de "accrlog".
  factaccr = exp (accrlog);
  % "XAp" et "XBp", regroupées sous le vecteur "Xp", sont les montants
  % respectifs possédés dans les actions A et B à la fin de l'opération.
  Xp = [XA; XB] .* factaccr;
  XAp = Xp(1);
  XBp = Xp(2);
  % On regarde si notre boursicoteur a assez pour rembourser la banque, avec les
  % intérêts.
  if XAp + XBp - Sinvest + Sperso < r * Sbanque
    defauts = defauts + 1;
  end
end
% Calcul de l'estimateur de Monte-Carlo et de sa variance, et affichage du
% résultat.
proba = defauts / Nsim;
var_i = proba * (1 - proba);
var_estr = var_i / Nsim;
fprintf ('Probabilité de défaut : %f %% ± %f.\n', ...
  100 * proba, 100 * 1.96 * sqrt (var_estr));
return
end