% Probabilité de défaut évitée par la nouvelle allocation de l'investissement, calculée avec couplage.
% Cette fonction prend en entrée le nombre "Nsim" de simulations demandées, et
% affiche l'estimation de la probabilité de défaut pour la 1re allocation moins
% la probabilité pour la 2e allocation. Je ne commente que les différences avec
% "defaut_simple".
function diffdefaut (Nsim)
global Sinvest Sbanque Sperso piA piB muA muB sigmaAA sigmaBB sigmaAB r ...
  piAbis piBbis
init_17bis ();
% Puisqu'on va simuler deux éventualités différentes à chaque fois, certaines
% variables doivent être découplées selon qu'on est dans la 1re ou la 2e
% éventualité : quand on est dans la 2e éventualité, cela sera signalé par le
% suffixe « bis ».
XA = piA * Sinvest;
XAbis = piAbis * Sinvest;
XB = piB * Sinvest;
XBbis = piBbis * Sinvest;
R = (chol ([sigmaAA sigmaAB; sigmaAB sigmaBB]))';
% La quantité dont on évalue l'espérance n'est plus une indicatrice à présent.
somme_d = 0;
somme_d2 = 0;
for i = 1 : Nsim
  % Le couplage naturel consiste à utiliser, quelle que soit l'éventualité, le
  % même accroissement de la valeur des actifs.
  accrlog = [muA; muB] + R * randn (2, 1);
  factaccr = exp (accrlog);
  Xp = [XA; XB] .* factaccr;
  Xpbis = [XAbis; XBbis] .* factaccr;
  XAp = Xp(1);
  XApbis = Xpbis(1);
  XBp = Xp(2);
  XBpbis = Xpbis(2);
  % On calcule la différence "diffind" entre les indicatrices de défaut pour
  % resp. la 1re et la 2e éventualité.
  diffind = 0;
  if XAp + XBp - Sinvest + Sperso < r * Sbanque
    diffind = diffind + 1;
  end
  if XApbis + XBpbis - Sinvest + Sperso < r * Sbanque
    diffind = diffind - 1;
  end
  somme_d = somme_d + diffind;
  somme_d2 = somme_d2 + diffind * diffind;
end
moy_d = somme_d / Nsim;
var_d = somme_d2 / Nsim - moy_d * moy_d;
ect_est = var_d / Nsim;
fprintf ('Probabilité de défaut évitée : %f %% ± %f.\n', ...
  100 * moy_d, 100 * 1.96 * sqrt (ect_est));
return
end
