% Probabilité de défaut relative évitée par la nouvelle allocation de l'investissement, calculée avec couplage.
% Cette fonction prend en entrée le nombre "Nsim" de simulations demandées, et
% affiche l'estimation de la probabilité de défaut pour la 1re allocation moins
% la probabilité pour la 2e allocation, divisée par la probabilité de défaut
% pour la 1re allocation. Je ne commente que les différences avec
% "defaut_simple".
function diffreldefaut (Nsim)
global Sinvest Sbanque Sperso piA piB muA muB sigmaAA sigmaBB sigmaAB r ...
  piAbis piBbis
init_17bis ();
XA = piA * Sinvest;
XAbis = piAbis * Sinvest;
XB = piB * Sinvest;
XBbis = piBbis * Sinvest;
R = (chol ([sigmaAA sigmaAB; sigmaAB sigmaBB]))';
% L'idée est simplement que la baisse relative du risque de défaut est une
% fonction de deux espérances… On reste sur un paradigme couplé. On utilise les
% mêmes notations que dans les programmes précédents, càd. que "defauts" (vue
% ici comme la somme de "inddefaut") comptabilisera les défauts dans la
% situation de base, et "somme_d" et "somme_d2" comptabiliseront la somme des
% différences des indicatrices de défaut, resp. de leurs carrés. Ici il faudra
% aussi introduire "somme_prod" pour la somme des produits de "inddefaut" et
% "diffind", qui interviendra pour le calcul de la variance de l'estimateur.
defauts = 0;
somme_d = 0;
somme_d2 = 0;
somme_prod = 0;
for i = 1 : Nsim
  accrlog = [muA; muB] + R * randn (2, 1);
  factaccr = exp (accrlog);
  Xp = [XA; XB] .* factaccr;
  Xpbis = [XAbis; XBbis] .* factaccr;
  XAp = Xp(1);
  XApbis = Xpbis(1);
  XBp = Xp(2);
  XBpbis = Xpbis(2);
  diffind = 0;
  if XAp + XBp - Sinvest + Sperso < r * Sbanque
    diffind = diffind + 1;
    inddefaut = 1;
  else
    inddefaut = 0;
  end
  if XApbis + XBpbis - Sinvest + Sperso < r * Sbanque
    diffind = diffind - 1;
  end
  defauts = defauts + inddefaut;
  somme_d = somme_d + diffind;
  somme_d2 = somme_d2 + diffind * diffind;
  somme_prod = somme_prod + inddefaut * diffind;
end
proba = defauts / Nsim;
var_i = proba * (1 - proba);
moy_d = somme_d / Nsim;
var_d = somme_d2 / Nsim - moy_d * moy_d;
moy_prod = somme_prod / Nsim;
% "covar" est (l'estimateur de) la covariance entre "inddefaut" et "diffind".
covar = moy_prod - proba * moy_prod;
% L'estimateur de la fonction d'espérances qui nous intéresse est simplement la
% fonction des estimateurs d'espérances.
estimateur = moy_d / proba;
% La formule pour la variance de "estimateur" découle des calculs théoriques sur
% la dérivée de la fonction quotient.
var_estr = var_d / Nsim / (proba * proba) ...
  + var_i / Nsim * (moy_d * moy_d) / (proba * proba * proba * proba) ...
  - 2 * covar / Nsim * moy_d / (proba * proba * proba);
fprintf ('La proportion de défauts évitée par la nouvelle allocation ');
fprintf ('est de %f %% ± %f.\n', ...
  100 * estimateur, 100 * 1.96 * sqrt (var_estr));
return
end