%% Simulation avec X mis à jour avant Y.
% Implémentation d'une méthode d'Euler incorrecte où on ferait la mise à jour de X avant celle de Y.
function simulation_01 (X0, Y0, T)
% Initialisation des paramètres.
global R dt
init_ordre ();
% Nombre de pas pour la simulation.
Npas = ceil (T / dt);
% On alloue la mémoire pour les vecteurs destinés à contenir resp. les
% des temps auxquelles on trace les simulations, ainsi que les valeurs de X et
% de Y en ces temps.
t_ = zeros (1, Npas + 1);
X_ = zeros (1, Npas + 1);
Y_ = zeros (1, Npas + 1);
% On initialise "t", "X" et "Y", qui contiendront les valeurs courantes de resp.
% le temps et les processus X_t et Y_t.
t = 0;
X = X0;
Y = Y0;
% On enregistre ces valeurs initiales dans les vecteurs de résultats.
t_(1) = t;
X_(1) = X;
Y_(1) = Y;
% Boucle pour la simulation par la méthode d'Euler stochastique.
for i = 1 : Npas
  % On calcule la longueur "pas" du pas de simulation qu'on va effectuer et on
  % met à jour le temps. En général le pas sera simplement égal à dt, mais le
  % dernier pas est susceptible d'avoir une longueur un peu plus courte si T
  % n'est pas un multiple de dt.
  if i == Npas
    pas = T - t;
    t = T;
  else
    pas = dt;
    t = t + pas;
  end
  % On simule l'incrément des mouvements browniens W^1 et W^3 par la méthode de Cholesky.
  % Notez que seul l'incrément brownien nous intéresse ici ; les processus W^1
  % et W^3 n'apparaissent jamais en tant que tels !
  dW13 = sqrt (pas) * R * randn (2, 1);
  % De même, on simule les incréments dW^2 et dW^4.
  dW2 = sqrt (pas) * randn ();
  dW4 = sqrt (pas) * randn ();
  % On met à jour X puis Y, selon la méthode imposée par l'énoncé.
  X = X + Y * dW13(1) + dW2;
  Y = Y + X * dW13(2) + dW4;
  % On enregistre les valeurs simulées dans le vecteur de résultats.
  X_(i + 1) = X;
  Y_(i + 1) = Y;
  t_(i + 1) = t;
end
% On trace la figure.
figure (1)
clf
hold on
plot (t_, X_, 'blue')
plot (t_, Y_, 'red')
hold off
xlim ([0, T]);
return
end
