%% Estimation de l'amélioration avec conditionnement.
% Cette fonction estime l'amélioration de la production journalière moyenne de
% l'usine apportée par la nouvelle chaine en combinant les techniques de
% couplage et de conditionnement. Il y a essentiellement à reprendre les
% éléments des codes de "MC_prod_cond" et "MC_prod_coupl" ; la vraie difficulté
% est surtout la programmation de la fonction "usine_prod_cond_coupl" qui fait
% tout le travail.
function MC_prod_cond_coupl (Nsim)
global risque z_risque
init_intermittences ();
somme_pc = 0;
somme_dpc = 0;
somme_dpc2 = 0;
for i = 1 : Nsim;
  % Comme nous l'avons dit, on va combiner conditionnement et couplage : en
  % fait, ce qu'on simule ici est un couple d'espérances conditionnelles
  % (judicieusement couplées) ; et la quantité qui nous intéresse est
  % l'espérance de la différence entre ces deux espérances conditionnelles, qui
  % est égale à la différence entre les espérances des espérances
  % conditionnelles, et donc à la différence des espérances tout court, comme
  % voulu.
  pc = usine_prod_cond_coupl ();
  dpc = pc(2) - pc(1);
  somme_pc = somme_pc + pc;
  somme_dpc = somme_dpc + dpc;
  somme_dpc2 = somme_dpc2 + dpc ^ 2;
end
esp_emp = somme_dpc / Nsim;
var_emp = somme_dpc2 / Nsim - esp_emp ^ 2;
est_Edp = esp_emp;
var_est = var_emp / Nsim;
ect_est = sqrt (var_est);
fprintf ('Première usine : %.0f.\n', somme_pc(1) / Nsim);
fprintf ('Seconde usine : %.0f.\n', somme_pc(2) / Nsim);
fprintf ('L''amélioration  de la production journalière moyenne est de ')
fprintf ('%.0f ± %.0f boulons (au risque %.1e).\n', ...
  est_Edp, z_risque * ect_est, risque);
end
