%% État du réseau et de l'usine, et production.
% Cette fonction simule et trace l'évolution de l'état du réseau électrique et
% de l'usine au cours de la journée, comme "usine_elec_graph", mais renvoie en
% outre la quantité de boulons produite au cours de cette journée, appelée
% "production". Je ne commente que les ajouts par rapport à "usine_elec_graph".
function production = elec_usine_graph_prod
% Il faut maintenant introduire aussi la variable globale "D".
global tdeb tfin taupan taurep Tpre ELEC_PANNE ELEC_OK ...
  USINE_ARRET USINE_PRECH USINE_FONCT PANNE CHAUD REPARE FIN D
init_intermittences ();
alloc_result = ceil (1.5 * (tfin - tdeb) / (taurep + taupan) * 6);
if alloc_result < 3
  alloc_result = 3;
end
t_graph = zeros (alloc_result, 1);
elec_graph = zeros (alloc_result, 1);
usine_graph = zeros (alloc_result, 1);
t = tdeb;
if rand < taupan / (taurep + taupan)
  elec = ELEC_PANNE;
  usine = USINE_ARRET;
  phenomene_prec = PANNE;
else
  elec = ELEC_OK;
  usine = USINE_PRECH;
  phenomene_prec = REPARE;
end
i = 1;
t_graph(i) = t;
elec_graph(i) = elec;
usine_graph(i) = usine;
% "production" est initialisée à zéro.
production = 0;
while true
  switch elec
    case ELEC_PANNE
      phenomene = REPARE;
      attente = taurep * (-log (rand ()));
    case ELEC_OK
      phenomene = PANNE;
      attente = taupan * (-log (rand ()));
  end
  if phenomene_prec == REPARE && attente > Tpre
    phenomene = CHAUD;
    attente = Tpre;
  end
  t = t + attente;
  if t > tfin
    phenomene = FIN;
    % Dans ce programme-ci, lorsque la simulation se termine, il faut aussi
    % corriger la longueur "attente" de la dernière étape simulée.
    attente = attente - (t - tfin);
    t = tfin;
  end
  i = i + 1;
  t_graph(i) = t;
  elec_graph(i) = elec;
  usine_graph(i) = usine;
  % On regarde le nombre de boulons produits pendant la période qui s'est
  % écoulée, période dont la durée est indiquée par "attente".
  if usine == USINE_FONCT
    production = production + attente * D;
  end
  switch phenomene
    case PANNE
      elec = ELEC_PANNE;
      usine = USINE_ARRET;
    case CHAUD
      usine = USINE_FONCT;
    case REPARE
      elec = ELEC_OK;
      usine = USINE_PRECH;
    case FIN
      break
  end
  i = i + 1;
  t_graph(i) = t;
  elec_graph(i) = elec;
  usine_graph(i) = usine;
  if i + 2 > alloc_result
    alloc_result = 2 * (i + 2);
    t_graph (alloc_result) = 0;
    elec_graph (alloc_result) = 0;
  end
  phenomene_prec = phenomene;
end
figure (1)
clf
hold on
plot (t_graph(1 : i), elec_graph (1 : i), 'red', 'LineWidth', 2);
plot (t_graph(1 : i), usine_graph (1 : i), 'cyan', 'LineWidth', 2);
hold off
axis ([tdeb, tfin, ELEC_PANNE, USINE_FONCT]);
return
end
