%% Espérance conditionnelle de la production journalière.
% Cette fonction calcule l'espérance de la production journalière
% conditionnellement à tout ce qui s'est passé jusqu'à l'heure t_fin-T_pre. Je
% ne commente que les différences avec "usine_prod".
function Eproduction = usine_prod_cond
global tdeb tfin taupan taurep Tpre ELEC_OK ELEC_PANNE ...
  USINE_ARRET USINE_PRECH USINE_FONCT REPARE CHAUD PANNE FIN D
t = tdeb;
if rand < taupan / (taurep + taupan)
  elec = ELEC_PANNE;
  usine = USINE_ARRET;
  phenomene_prec = PANNE;
else
  elec = ELEC_OK;
  usine = USINE_PRECH;
  phenomene_prec = REPARE;
end
production = 0;
while true
  if elec == ELEC_OK
    attente = taupan * (-log (rand ()));
    phenomene = PANNE;
  else
    attente = taurep * (-log (rand ()));
    phenomene = REPARE;
  end
  if phenomene_prec == REPARE && attente > Tpre
    phenomene = CHAUD;
    attente = Tpre;
  end
  % La pemière différence est qu'on sort de la boucle dès qu'on atteint le temps
  % t_fin-T_pre (et non plus t_fin), puisque c'est à ce moment-là qu'on
  % conditionne.
  t = t + attente;
  if t > tfin - Tpre
    phenomene = FIN;
    attente = attente - (t - (tfin - Tpre));
    t = tfin - Tpre;
  end
  if usine == USINE_FONCT
    production = production + attente * D;
  end
  if phenomene == REPARE
    elec = ELEC_OK;
    usine = USINE_PRECH;
  elseif phenomene == CHAUD
    usine = USINE_FONCT;
  elseif phenomene == PANNE
    elec = ELEC_PANNE;
    usine = USINE_ARRET;
  elseif phenomene == FIN
    break
  end
  phenomene_prec = phenomene;
end
% Il faut mainteant calculer l'espérance de la production résiduelle entre
% t_fin-T_pre et t_fin (conditionnellement à ce qu'on a simulé, s'entend), qu'on
% appellera "Eresidu". Pour cela on utilise la formule calculée théoriquement.
switch usine
  case USINE_ARRET
    Eresidu = 0;
  case usine == USINE_PRECH
    % Dans le cas où l'usine est en préchauffage à l'heure t_fin-T_pre, la durée
    % depuis laquelle elle préchauffe est indiquée par "attente".
    Eresidu = D * taupan * exp (-Tpre / taupan) * (exp (attente / taupan) - 1);
  case USINE_FONCT
    Eresidu = D * taupan * (1 - exp (-Tpre / taupan));
end
% L'espérance conditionnelle de la production est alors la production jusqu'à
% t_fin-T_pre, plus l'espérance de la production résiduelle.
Eproduction = production + Eresidu;
return
end
