%% Productions journalières couplées.
% Cette fonction simule de façon couplée la production de l'usine avec
% l'ancienne ou avec la nouvelle chaine de production, le couplage consistant à
% faire arriver les pannes et les réparations du réseau électrique au même
% moment dans les deux cas. La fonction renvoie le couple (production pour
% l'ancienne chaine, production pour la nouvelle chaine).
function productions = usine_prod_coupl
% Il y a un nouveau phénomène potentiel à prendre en compte, appelé "DEMICHAUD",
% lorsque la nouvelle chaine a fini son préchauffage et passe en phase de
% fonctionnement (l'ancienne chaine étant alors toujours en préchauffage).
global tdeb tfin taupan taurep Tpre Tpre_neo ELEC_PANNE ELEC_OK ...
  USINE_ARRET USINE_PRECH USINE_FONCT PANNE DEMICHAUD CHAUD REPARE FIN D
t = tdeb;
% On appelle "usine" l'état de l'usine pour l'ancienne chaine de production,
% resp. "usine_neo" l'état de l'usine pour la nouvelle chaine.
if rand < taupan / (taurep + taupan)
  elec = ELEC_PANNE;
  usine = USINE_ARRET;
  usine_neo = USINE_ARRET;
  phenomene_prec = PANNE;
else
  elec = ELEC_OK;
  usine = USINE_PRECH;
  usine_neo = USINE_PRECH;
  phenomene_prec = REPARE;
end
% On appelle "production" la production pour l'ancienne chaine de montage, resp.
% "production_neo" la production pour la nouvelle chaine.
production = 0;
production_neo = 0;
while true
  switch elec
    case ELEC_PANNE
      phenomene = REPARE;
      attente = taurep * (-log (rand ()));
    case ELEC_OK
      phenomene = PANNE;
      attente = taupan * (-log (rand ()));
  end
  % Si le dernier phénomène qui s'est produit était le rétablissement de
  % l'électricité, on regarde si le temps d'attente est suffisant pour que la
  % nouvelle chaine de montage se remette en fonctionnement.
  if phenomene_prec == REPARE && attente > Tpre_neo
    phenomene = DEMICHAUD;
    attente = Tpre_neo;
    % Si le dernier phénomène qui s'est produit était la remise en
    % fonctionnement de la nouvelle chaine, on regarde si le temps d'attente est
    % suffisant pour que l'ancienne chaine se remette en fonctionnement à son
    % tour.
  elseif phenomene_prec == DEMICHAUD && attente > Tpre - Tpre_neo
    phenomene = CHAUD;
    attente = Tpre - Tpre_neo;
  end
  t = t + attente;
  if t > tfin
    phenomene = FIN;
    attente = attente - (t - tfin);
    t = tfin;
  end
  % On met à jour resp. "production" et "production_neo".
  if usine == USINE_FONCT
    production = production + attente * D;
  end
  if usine_neo == USINE_FONCT
    production_neo = production_neo + attente * D;
  end
  % Il y a maintenant cinq phénomènes possibles à prendre en compte.
  switch phenomene
    case PANNE
      elec = ELEC_PANNE;
      usine = USINE_ARRET;
      usine_neo = USINE_ARRET;
    case DEMICHAUD
      usine_neo = USINE_FONCT;
    case CHAUD
      usine = USINE_FONCT;
    case REPARE
      elec = ELEC_OK;
      usine = USINE_PRECH;
      usine_neo = USINE_PRECH;
    case FIN
      break
  end
  phenomene_prec = phenomene;
end
% On agrège "production" et "production_neo" dans "productions".
productions = [production, production_neo];
return
end
