%% Simulation pour la méthode de Monte-Carlo naïve.
% Cette fonction simule le mouvement brownien et renvoie "succes" indiquant si
% la trajectoire est passé au-delà de 1+1/2 au temps 1/2 avant de redescendre
% en-dessous en 0 au temps 1.
function succes = simulation_P
% Introduction de quelques notations : "dt" est le pas de temps, "t1" l'instant
% où le mouvement brownien doit avoir franchi le seuil "s1", "t2" l'instant où
% le mouvement brownien doit être revenu sous le seuil "s2".
dt = 2 ^ -12;
t2 = 1;
s1 = 1 + 1 / 2;
s2 = 0;
% "t" est le temps courant et "X" la valeur courante du mouvement brownien.
t = 0;
X = 0;
succes = false;
% "critere1" dit si on a rempli le premier critère de la condition de succès.
critere1 = false;
% Simulation entre 0 et t1.
while t < t2
  t = t + dt;
  if t > t2
    pas = dt - (t2 - t);
    t = t2;
  else
    pas = dt;
  end
  X = X + sqrt (pas) * randn ();
  if X > s1
    critere1 = true;
  end
  if critere1 && X < s2
    succes = true;
  end
end
% On renvoie le résultat.
return
end
