%% Simulation pour la méthode de Monte-Carlo préférentielle.
% Cette fonction simule le mouvement brownien sous la loi d'échantillonnage
% préférentiel. Elle indique, d'une part si l'évènement qui nous intéresse s'est
% réalisé, et d'autre part la densité de la nouvelle simulation par rapport à
% l'ancienne.
function [succes, densite] = simulation_Q
dt = 2 ^ -12;
t1 = 1 / 2;
t2 = 1;
s1 = 1 + 1 / 2;
s2 = 0;
t0 = 0;
t = t0;
X0 = 0;
X = X0;
densite = 1;
succes = false;
critere1 = false;
derive1 = 1;
derive2 = -1;
% Cette fois-ci il va s'avérer plus judicieux de faire la simulation en deux
% phases.
while t < t1
  t = t + dt;
  if t > t1
    pas = dt - (t1 - t);
    t = t1;
  else
    pas = dt;
  end
  % Il faut maintenant tenir compte aussi du terme de dérive.
  X = X + sqrt (pas) * randn () + derive1 * pas;
  if X > s1
    critere1 = true;
  end
  if critere1 && X < s2
    succes = true;
  end
end
X1 = X;
densite = densite * exp (derive1 * (X1 - X0) - derive1 ^ 2 / 2 * (t1 - t0));
% Simulation entre t1 et t2.
while t < t2
  t = t + dt;
  if t > t2
    pas = dt - (t2 - t);
    t = t2;
  else
    pas = dt;
  end
  % Le terme de dérive a changé…
  X = X + sqrt (pas) * randn () + derive2 * pas;
  if X > s1
    critere1 = true;
  end
  if critere1 && X < s2
    succes = true;
  end
end
X2 = X;
densite = densite * exp (derive2 * (X2 - X1) - derive2 ^ 2 / 2 * (t2 - t1));
return
end
