%% Probabilités d'extinction et de survie.
% Cette fonction estime les probabilités resp. d'extinction et de survie de
% l'espèce, sur une échelle de temps "T", en partant de "Xdeb" femelles et
% "Ydeb" mâles, par la méthode de Monte-Carlo avec "Nsim" simulations. Elle
% affiche les valeurs calculées, assorties de leurs marges d'erreur, et ne
% renvoie rien. La partie “Monte-Carlo” du code est classique et se passe donc
% de commentaires : il faut juste savoir que le travail de simulation est opéré
% par la fonction "simulation_muette", qui renvoie un booléen disant si l'espèce
% a survécu ou non lors de la simulation.
function proba_ES (Xdeb, Ydeb, T, Nsim)
global risque z_risque
init_PNM ();
Nextinct = 0;
Nsurvie = 0;
for i = 1 : Nsim
  survie = simulation_muette (Xdeb, Ydeb, T);
  if survie
    Nsurvie = Nsurvie + 1;
  else
    Nextinct = Nextinct + 1;
  end
end
pextinct_emp = Nextinct / Nsim;
psurvie_emp = Nsurvie / Nsim;
var_indextinct_emp = pextinct_emp * (1 - pextinct_emp);
var_indsurvie_emp = psurvie_emp * (1 - psurvie_emp);
est_pextinct = pextinct_emp;
est_psurvie = psurvie_emp;
var_est_pextinct = var_indextinct_emp / Nsim;
var_est_psurvie = var_indsurvie_emp / Nsim;
ect_est_pextinct = sqrt (var_est_pextinct);
ect_est_psurvie = sqrt (var_est_psurvie);
fprintf ('La probabilité d''extinction vaut %.2f %% ± %.2f.\n', ...
  100 * est_pextinct, 100 * z_risque * ect_est_pextinct);
fprintf ('La probabilité de survie vaut %.2f %% ± %.2f.\n', ...
  100 * est_psurvie, 100 * z_risque * ect_est_psurvie);
fprintf ('(Niveau de risque : %.2e).\n', risque);
return
end
