%% Probabilités d'extinction et de survie avec échantillonnage préférentiel.
% Ce programme fonctionne comme "proba_ES", à ceci près qu'on va utiliser une
% loi d'échantillonnage préférentiel dont le paramètre est indiqué par
% l'opérateur comme "beta0bis". Je ne commente que les spécificités liées à
% l'échantillonnage préférentiel.
function proba_ES_pref (Xdeb, Ydeb, T, beta0bis, Nsim)
global risque z_risque
init_PNM ();
% Du fait de l'échantillonnage préférentiel, le calcul ne s'apparente plus à
% l'espérance d'une indicatrice : il faut donc maintenir séparément la somme et
% la somme des carrés (avec des noms de variables transparents).
somme_extinct = 0;
somme_extinct2 = 0;
somme_survie = 0;
somme_survie2 = 0;
for i = 1 : Nsim
  % Lors de chaque simulation, il faut, d'une part savoir si la simulation a
  % conduit à la survie ou non (ce qu'on stocke dans le booléen "ilyasurvie"),
  % et d'autre part connaitre la densité relative pour cette simulation (stockée
  % dans "densite"). Ce travail est effectué par la fonction
  % "simulation_muette_pref".
  [ilyasurvie, densite] = simulation_muette_pref (Xdeb, Ydeb, T, beta0bis);
  % On déduit des résultats de "simulation_muette_pref" la valeur des variables
  % aléatoires dont on s'intéresse aux espérances, variables appelées resp.
  % "extinct" et "survie" selon qu'elles se rapportent à la probabilité
  % d'extinction ou de survie. Attention à un piège : Comme
  % "simulation_muette_pref" calcule la densité /de la loi préférentielle par
  % rapport à la vraie loi/, dans ce programme on doit /diviser/ par la densité
  % !
  if ilyasurvie
    survie = 1 / densite;
    extinct = 0;
  else
    survie = 0;
    extinct = 1 / densite;
  end
  somme_survie = somme_survie + survie;
  somme_extinct = somme_extinct + extinct;
  somme_survie2 = somme_survie2 + survie ^ 2;
  somme_extinct2 = somme_extinct2 + extinct ^ 2;
end
esp_extinct_emp = somme_extinct / Nsim;
esp_survie_emp = somme_survie / Nsim;
var_extinct_emp = somme_extinct2 / Nsim - esp_extinct_emp ^ 2;
var_survie_emp = somme_survie2 / Nsim - esp_survie_emp ^ 2;
est_pextinct = esp_extinct_emp;
est_psurvie = esp_survie_emp;
var_est_pextinct = var_extinct_emp / Nsim;
var_est_psurvie = var_survie_emp / Nsim;
ect_est_pextinct = sqrt (var_est_pextinct);
ect_est_psurvie = sqrt (var_est_psurvie);
fprintf ('La probabilité d''extinction vaut %.2f %% ± %.2f.\n', ...
  100 * est_pextinct, 100 * z_risque * ect_est_pextinct);
fprintf ('La probabilité de survie vaut %.2f %% ± %.2f.\n', ...
  100 * est_psurvie, 100 * z_risque * ect_est_psurvie);
fprintf ('(Niveau de risque : %.2e).\n', risque);
return
end
