%% Estimation de p via q, par méthode de Monte-Carlo naïve.
% Cette fonction fonctionne comme "MC_p", mais passe plutôt par l'estimation de
% la probabilité q. Je ne commente que les différences avec "MC_p".
function MC_q (Nsim)
global Z F D risque z_risque
init_Dudo ();
Nsucces = 0;
for i = 1 : Nsim
  % On ne peut pas utiliser directement la fonction "simulation" ici vu que
  % l'évènement considéré n'est pas le même ; j'écris donc à l'intérieur du code
  % de "MC_q" un code inspiré de "simulation" qui simule si le nouvel évènement
  % considéré se réalise.
  des = zeros (Z, 1);
  for j = 1 : Z
    des(j) = ceil (F * rand ());
  end
  nombre = zeros (F, 1);
  for j = 1 : Z
    nombre(des(j)) = nombre(des(j)) + 1;
  end
  % Astuce : Pour trier un (multi-)ensemble d'entiers en départageant les
  % ex-æquos uniformément, on peut ajouter à chacun de ces entiers une partie
  % fractionnaire aléatoire indépendante (de loi sans atome) (en l'occurrence
  % j'ajoute une partie fractionnaire uniforme entre 0 et 1), et trier les réels
  % ainsi obtenus (puis on reviendra aux entiers en prenant la partie entière).
  for k = 1 : F
    nombre(k) = nombre(k) + rand ();
  end
  % On regarde si ‘1’ est le chiffre record, ce qu'on stockera dans le booléen
  % "record". Pour ce faire, on initialise "record" à vrai et on compare le
  % score de ‘1’ à celui de chaque autre chiffre.
  record = true;
  for k = 2 : F
    record = record && (nombre(1) > nombre(k));
  end
  % Il y a succès si ‘1’ est le nombre record et que le nombre de succès
  % correspondant vaut au moins D.
  succes = record && (floor (nombre(1)) >= D);
  if succes
    Nsucces = Nsucces + 1;
  end
end
pba_succ_emp = Nsucces / Nsim;
var_succ_emp = pba_succ_emp * (1 - pba_succ_emp);
% Calcul de l'estimateur de q et de sa variance.
est_q = pba_succ_emp;
var_est_q = var_succ_emp / Nsim;
% On en déduit l'estimateur de p et sa variance.
est_p = F * est_q;
var_est_p = F ^ 2 * var_est_q;
ect_est_p = sqrt (var_est_p);
fprintf ('Au risque %.1e, p vaut %f %% ± %f.\n', risque, 100 * est_p, ...
  100 * z_risque * ect_est_p);
return
end
