%% Estimation de q avec variable de contrôle, version rudimentaire.
% Amélioration de "MC_q" en utilisant la variable de contrôle suggérée par
% l'énoncé. Je ne commente que les différences avec "MC_q".
function MC_q_ctrl (Nsim)
global Z F D risque z_risque
init_Dudo ();
% Initialisation des sommes. On désigne par le suffixe 'f' l'indicatrice
% corrigée par la variable de contrôle.
som_f = 0;
som_f2 = 0;
for i = 1 : Nsim
  % Simulation du résultat des dés ; l'évènement considéré est-il réalisé ?
  % (voir les commentaires de cette partie du code dans "MC_q"). On stocke
  % l'indicatrice correspondante dans "ind".
  des = zeros (Z, 1);
  for j = 1 : Z
    des(j) = ceil (F * rand ());
  end
  nombre = zeros (F, 1);
  for j = 1 : Z
    nombre(des(j)) = nombre(des(j)) + 1;
  end
  for k = 1 : F
    nombre(k) = nombre(k) + rand ();
  end
  record = true;
  for k = 2 : F
    record = record && (nombre(1) > nombre(k));
  end
  if record && (floor (nombre(1)) >= D);
    ind = 1;
  else
    ind = 0;
  end
  % Calcul de la variable A, puis de la variable de contrôle "ctrl".
  A = 0;
  for j = 1 : Z
    if des(j) == 1
      A = A + 1;
    end
  end
  ctrl = (F * A - Z) ^ 2 / (F * D - Z) ^ 2 / 2;
  % Calcul de "f", l'indicatrice corrigée par la variable de contrôle.
  f = ind - ctrl;
  % Mise à jour des sommes.
  som_f = som_f + f;
  som_f2 = som_f2 + f ^ 2;
end
% Statistiques de nos simulations.
esp_f_emp = som_f / Nsim;
var_f_emp = som_f2 / Nsim - esp_f_emp ^ 2;
% "esp_ctrl" est l'espérance (exacte) de la variable de contrôle.
esp_ctrl = Z * (F - 1) / (F * D - Z) ^ 2 / 2;
% Calcul de l'estimateur de q et de sa variance.
est_q = esp_f_emp + esp_ctrl;
var_est_q = var_f_emp / Nsim;
% La fin du code est identique à "MC_q".
est_p = F * est_q;
var_est_p = F ^ 2 * var_est_q;
ect_est_p = sqrt (var_est_p);
fprintf ('Au risque %.1e, p vaut %f %% ± %f.\n', risque, 100 * est_p, ...
  100 * z_risque * ect_est_p);
return
end
