%% Estimation de q avec variable de contrôle, version avancée.
% L'interface est la même que pour "MC_q_ctrl". On utilise trois variables de
% contrôle de base : A, A^2 et A^3. Je ne commente que les différences avec
% "MC_q_ctrl".
function MC_q_ctrl_avance (Nsim)
global Z F D risque z_risque
init_Dudo ();
% On désigne par le suffixe 'ind' l'indicatrice qui nous intéresse ; et par
% 'ctrlx' les variables de contrôle. Notez que nous allons traiter les variables
% de contrôle à l'aide du formalisme matriciel, les indices respectifs 1, 2 et 3
% correspondant aux variables de contrôle A, A^2 et A^3. Remarquer qu'il s'avère
% inutile de calculer "som_ind2" en l'occurrence.
som_ind = 0;
% "somme_ctrlx(i)" sera la somme des simulations de la i-ième variable de
% contrôle.
som_ctrlx = zeros (3, 1);
% "som_indctrlx(i)" sera la somme des produits de l'indicatrice par la i-ième
% variable de contrôle.
som_indctrlx = zeros (3, 1);
% "som_ctrlx2(i, j)" sera la somme des produits de la i-ième variable de
% contrôle par la j-ième variable de contrôle.
som_ctrlx2 = zeros (3, 3);
for i = 1 : Nsim
  des = zeros (Z, 1);
  for j = 1 : Z
    des(j) = ceil (F * rand ());
  end
  nombre = zeros (F, 1);
  for j = 1 : Z
    nombre(des(j)) = nombre(des(j)) + 1;
  end
  for k = 1 : F
    nombre(k) = nombre(k) + rand ();
  end
  record = true;
  for k = 2 : F
    record = record && (nombre(1) > nombre(k));
  end
  if record && (floor (nombre(1)) >= D);
    ind = 1;
  else
    ind = 0;
  end
  % Calcul de la variable A, puis des variables de contrôle.
  A = 0;
  for j = 1 : Z
    if des(j) == 1
      A = A + 1;
    end
  end
  ctrlx = [A; A ^ 2; A ^ 3];
  % Mise à jour des sommes.
  som_ind = som_ind + ind;
  som_ctrlx = som_ctrlx + ctrlx;
  som_indctrlx = som_indctrlx + ind * ctrlx;
  % Notez comment, à l'aide du formalisme matriciel, on exprime en une seule
  % formule l'ensemble des produits des variables de contrôle.
  som_ctrlx2 = som_ctrlx2 + ctrlx * ctrlx';
end
esp_ind_emp = som_ind / Nsim;
% La variance de l'indicatrice se déduit directement de son espérance.
var_ind_emp = (1 - esp_ind_emp) * esp_ind_emp;
esp_ctrlx_emp = som_ctrlx / Nsim;
% Notez les formules matricielles pour calculer d'un coup les covariances
% (empiriques) entre l'indicatrice et les variables de contrôle, puis toute la
% matrice de covariance des variables de contrôle, notée "var_ctrlx_emp"
% (var_ctrlx_emp(i,j) étant la covariance empirique entre les i-ième et j-ième
% variables de contrôle).
cov_indctrlx_emp = som_indctrlx / Nsim - esp_ind_emp * esp_ctrlx_emp;
var_ctrlx_emp = som_ctrlx2 / Nsim - esp_ctrlx_emp * esp_ctrlx_emp';
% Calcul des coefficients pour la variable de contrôle optimale, regroupés dans
% le vecteur "lx" ; et affichage du résultat à titre informatif.
lx = var_ctrlx_emp \ cov_indctrlx_emp;
fprintf ('Pour information : ');
fprintf ('Au vu des simulations, notre programme va utiliser ');
fprintf ('la variable de contrôle %f * A + %f * A^2 + %f * A^3.\n', ...
  lx(1), lx(2), lx(3));
% Espérance et variance empiriques de la variable corrigée, désignée par le
% suffixe 'f'. Notez encore une fois l'emploi du formalisme matriciel.
esp_f_emp = esp_ind_emp - lx' * esp_ctrlx_emp;
var_f_emp = var_ind_emp - 2 * lx' * cov_indctrlx_emp + lx' * var_ctrlx_emp * lx;
% Espérances (exactes) des variables de contrôle, puis de la variable de
% contrôle optimale.
esp_ctrlx = [Z / F; Z / F + Z * (Z - 1) / F ^ 2; ...
  Z / F + 3 * Z * (Z - 1) / F ^ 2 + Z * (Z - 1) * (Z - 2) / F ^ 3];
esp_ctrl = lx' * esp_ctrlx;
% La fin du code est identique à "MC_q_ctrl".
est_q = esp_f_emp + esp_ctrl;
var_est_q = var_f_emp / Nsim;
est_p = F * est_q;
var_est_p = F ^ 2 * var_est_q;
ect_est_p = sqrt (var_est_p);
fprintf ('Au risque %.1e, p vaut %f %% ± %f.\n', risque, 100 * est_p, ...
  100 * z_risque * ect_est_p);
return
end
