%% Estimation de q avec échantillonnage préférentiel.
% L'interface est la même que pour "MC_q". On utilise la loi d'échantillonnage
% préférentiel suggérée par l'énoncé. Je ne commente que les points spécifiques
% à l'échantillonnage préférentiel.
function MC_q_pref (Nsim)
global Z F D risque z_risque pba1_biaisee pba2_biaisee
init_Dudo ();
% Initialisation des sommes. On désigne par le suffixe 'f' l'indicatrice de la
% fonction d'intérêt sous la loi d'échantillonnage préférentiel.
som_f = 0;
som_f2 = 0;
for i = 1 : Nsim
  des = zeros (Z, 1);
  % Cette fois-ci la simulation a lieu sous la loi d'échantillonnage
  % préférentiel. Il faut aussi, en même temps qu'on effectue la simulation,
  % calculer la densité relative de l'ancienne loi par rapport à la nouvelle,
  % appelée "densite".
  densite = 1;
  for j = 1 : Z
    % On simule la loi biaisée du résultat d'un dé par la méthode de la fonction
    % de répartition.
    u = rand ();
    if u < pba1_biaisee
      des(j) = 1;
      densite = densite / (F * pba1_biaisee);
    else
      des(j) = 2 + floor ((u - pba1_biaisee) / pba2_biaisee);
      densite = densite / (F * pba2_biaisee);
    end
  end
  nombre = zeros (F, 1);
  for j = 1 : Z
    nombre(des(j)) = nombre(des(j)) + 1;
  end
  % Notez que la façon de départager les ex-æquos ne change pas sous la loi
  % préférentielle : il n'y a donc pas lieu de modifier la densité dans cette
  % partie du code.
  for k = 1 : F
    nombre(k) = nombre(k) + rand ();
  end
  record = true;
  for k = 2 : F
    record = record && (nombre(1) > nombre(k));
  end
  if record && (floor (nombre(1)) >= D);
    ind = 1;
  else
    ind = 0;
  end
  % Calcul de f à partir de l'indicatrice.
  f = densite * ind;
  som_f = som_f + f;
  som_f2 = som_f2 + f ^ 2;
end
esp_f_emp = som_f / Nsim;
var_f_emp = som_f2 / Nsim - esp_f_emp ^ 2;
% Calcul de l'estimateur de q et de sa variance.
est_q = esp_f_emp;
var_est_q = var_f_emp / Nsim;
% La fin du code est identique aux programmes précédents.
est_p = F * est_q;
var_est_p = F ^ 2 * var_est_q;
ect_est_p = sqrt (var_est_p);
fprintf ('Au risque %.1e, p vaut %f %% ± %f.\n', risque, 100 * est_p, ...
  100 * z_risque * ect_est_p);
return
end
