%% Obtient-on D dés identiques ?
% Cette fonction simule le lancer de Z dés à F faces et regarde s'il y en a D au
% moins qui affichent le même chiffre. Elle ne prend aucun argument et renvoie
% le booléen "succes" indiquant si l'évènement considéré est réalisé.
function succes = simulation ()
% Déclaration des paramètres globaux.
global Z F D
% Remarque : Cette fonction n'étant pas destinée à être appelée depuis la
% console, je n'y initialise pas les paramètres globaux, car sinon on se
% retrouverait à ré-initialiser ces paramètres à chaque appel de "simulation"
% depuis une fonction-mère, d'où perte de temps… En revanche, si vous souhaitez
% tester "simulation" depuis la console, il faudra alors décommenter la ligne
% suivante.
%init_Dudo ();
% "des" est un Z-vecteur qui contiendra les résultats de chaque dé.
des = zeros (Z, 1);
% On simule un par un les résultats de chaque dé.
for j = 1 : Z
  % Noter comment on simule un entier uniforme entre 1 et F.
  des(j) = ceil (F * rand ());
end
% "nombre(k)" est destiné à contenir le nombre de dés affichant le chiffre k.
% C'est donc un F-vecteur, qu'on initialise à zéro.
nombre = zeros (F, 1);
% On parcourt les résultats des différents dés pour compter au fur et à mesure
% combien de fois chaque chiffre apparait. Noter que nous aurions pu fusionner
% cette boucle avec la précédente : en fait, dans le cadre de ce problème, nous
% n'étions même pas obligés de créer une variable "des", puisque seul "nombre"
% (que nous aurions pu simuler directement) nous intéresse ; cela pourrait
% d'ailleurs s'avérer utile si Z était très grand et que nous voulions
% économiser la mémoire.
for j = 1 : Z
  nombre(des(j)) = nombre(des(j)) + 1;
end
% On initialise "succes" à faux ; et on passe en revue les différents chiffres,
% en faisant basculer "succes" à vrai si l'un des chiffres apparait au moins D
% fois.
succes = false;
for k = 1 : F
  succes = succes || (nombre(k) >= D);
end
% On renvoie le résultat obtenu.
return
end
