%% Méthode de Buffon avec variable de contrôle, version avancée.
% Cette fonction est une variante de "Buffon_ctrl" and laquelle on cherche la
% meilleure variable de contrôle parmi les combinaisons linéaires de
% \sin(\theta)^2 et \sin(\theta)^4, selon la méthode décrite à la § 3.7.3 du
% polycopié. Je ne commente que les différences avec "Buffon_ctrl".
function Buffon_ctrl_avance ()
global a l risque z_risque
init_Buffon ();
Z = 1000000;
% Cette fois-ci on ne connait pas notre variable de contrôle à l'avance au
% moment de lancer la boucle de simulations. On va donc devoir maintenir les
% informations relatives à trois variables : la quantité qui nous intéresse en
% dernier lieu, à savoir \bar{n} (désignée par le suffixe 'nb'), et les deux
% variables de contrôle de base, à \sin(\theta)^2 et \sin(\theta)^4 (désignées
% respectivements par 'vca' et 'vcb'). Notez qu'il y a alors pas moins de 9
% sommes à calculer !
som_nb = 0;
som_nb2 = 0;
som_vca = 0;
som_vcb = 0;
som_nbvca = 0;
som_nbvcb = 0;
som_vca2 = 0;
som_vcb2 = 0;
som_vcavcb = 0;
for i = 1 : Z
  cossintheta = sim_theta ();
  sintheta = cossintheta(2);
  % Dans notre boucle, on va juste calculer \bar{n}, \sin(\theta)^2 et
  % \sin(\theta)^4, et mettre à jour les sommes associées.
  nb = a / l * sintheta;
  vca = sintheta ^ 2;
  vcb = sintheta ^ 4;
  som_nb = som_nb + nb;
  som_nb2 = som_nb2 + nb ^ 2;
  som_vca = som_vca + vca;
  som_vcb = som_vcb + vcb;
  som_nbvca = som_nbvca + nb * vca;
  som_nbvcb = som_nbvcb + nb * vcb;
  som_vca2 = som_vca2 + vca ^ 2;
  som_vcb2 = som_vcb2 + vcb ^ 2;
  som_vcavcb = som_vcavcb + vca * vcb;
end
% On calcule toutes les espérances, variances et covariances empiriques
% associées à nos simulations.
esp_nb_emp = som_nb / Z;
esp_vca_emp = som_vca / Z;
esp_vcb_emp = som_vcb / Z;
var_nb_emp = som_nb2 / Z - esp_nb_emp ^ 2;
var_vca_emp = som_vca2 / Z - esp_vca_emp ^ 2;
var_vcb_emp = som_vcb2 / Z - esp_vcb_emp ^ 2;
cov_nbvca_emp = som_nbvca / Z - esp_nb_emp * esp_vca_emp;
cov_nbvcb_emp = som_nbvcb / Z - esp_nb_emp * esp_vcb_emp;
cov_vcavcb_emp = som_vcavcb / Z - esp_vca_emp * esp_vcb_emp;
% Nous allons maintenant en déduire le vecteur (\lambda_a,\lambda_b), appelé
% "lx", des coefficients respectifs de \sin(\theta)^2 et \sin(\theta)^4 qui
% donnent lieu à la meilleure variable de contrôle. Pour cela, on utilise le
% formalisme matriciel, en utilisant le suffixe 'vcx' pour se référer au vecteur
% (\sin(\theta)^2,\sin(\theta)^4).
cov_nbvcx_emp = [cov_nbvca_emp; cov_nbvcb_emp];
var_vcx_emp = [var_vca_emp, cov_vcavcb_emp; cov_vcavcb_emp, var_vcb_emp];
lx = var_vcx_emp \ cov_nbvcx_emp;
la = lx(1);
lb = lx(2);
% Les lignes suivantes peuvent être omises : elles servent à afficher à titre
% d'information, quelle est la variable de contrôle qui va effectivement être
% utilisée.
fprintf ('Pour information : ');
fprintf ('Au vu des simulations, notre programme va utiliser ');
fprintf ('la variable de contrôle %f * \\sin(\\theta)^2 ', la);
fprintf ('+ %f * \\sin(\\theta)^4 ', lb);
fprintf ('pour le calcul de E(\bar{n}).\n');
% Ce n'est que maintenant que nous reconstituons à postériori, par
% (bi)linéarité, les espérance et variance empiriques de la variable \bar{n}
% corrigée de la variable de contrôle, variable corrigée que nous notons par le
% suffixe 'f'.
esp_f_emp = esp_nb_emp - la * esp_vca_emp - lb * esp_vcb_emp;
var_f_emp = var_nb_emp + la ^ 2 * var_vca_emp + lb ^ 2 * var_vcb_emp ...
  - 2 * la * cov_nbvca_emp - 2 * lb * cov_nbvcb_emp ...
  + 2 * la * lb * cov_vcavcb_emp;
% Maintenant nous déterminons l'espérance (exacte) ne notre variable de
% contrôle, notée par le suffixe 'vc', à partir des espérances (exactes) des
% variables de contrôle individuelles.
esp_vca = 1 / 2;
esp_vcb = 3 / 8;
esp_vc = la * esp_vca + lb * esp_vcb;
% Ça y est, nous nous sommes enfin raccrochés à la formulation rudimentaire de
% la variable de contrôle ! Il ne nous reste donc plus quà finir les calculs
% comme dans "Buffon_ctrl".
est_nu = esp_f_emp + esp_vc;
var_est_nu = var_f_emp / Z;
est_pi = 2 * a / l / est_nu;
var_est_pi = (2 * a / l / est_nu ^ 2) ^ 2 * var_est_nu;
fprintf ('Au risque %.1e, \\pi est compris dans l''intervalle ', risque);
fprintf ('[%f, %f].\n', est_pi - z_risque * sqrt (var_est_pi), ...
  est_pi + z_risque * sqrt (var_est_pi));
return
end
