%% Simulation de l'expérience de Buffon avec un-million d'allumettes.
% Cette fonction n'a ni entrée ni sortie ; elle affiche l'intervalle de
% confiance pour \pi calculé suite à la simulation.
function Buffon_noncond ()
% Initialisation des paramètres globaux.
global a l risque z_risque
init_Buffon ();
% "Z" est le nombre d'expériences à réaliser.
Z = 1000000;
% "N" va compter le nombre de croisements avec le bord des lattes.
N = 0;
% "som_n2" est la somme des n_i^2.
som_n2 = 0;
% Boucle de Monte-Carlo
for i = 1 : Z
  % "ytilde" correspond à \tilde{y}_i, uniforme entre 0 et l.
  ytilde = rand () * l;
  % On simule le couple (\cos(\theta),\sin(\theta)), appelé "cossintheta". Le
  % sinus en lui-même est appelé "sintheta".
  cossintheta = sim_theta ();
  sintheta = cossintheta(2);
  % "ymin" et "ymax" sont les ordonnées respectives des extrêmités basse et
  % haute de l'aiguille.
  ymin = ytilde - sintheta * a / 2;
  ymax = ytilde + sintheta * a / 2;
  % "n" est le nombre de croisements de notre aiguille avec les bords des
  % lattes. Il se calcule comme la différence entre les “numéros” des lattes de
  % chaque extrêmité de l'aiguille.
  n = floor (ymax / l) - floor (ymin / l);
  % On met les sommes à jour.
  N = N + n;
  som_n2 = som_n2 + n ^ 2;
end
% Calcul des paramètres empiriques de la loi de n que nous avons simulée dans
% cette expérience.
esp_n_emp = N / Z;
var_n_emp = som_n2 / Z - esp_n_emp ^ 2;
% On en déduit l'estimateur de \nu ainsi que sa variance.
est_nu = esp_n_emp;
var_est_nu = var_n_emp / Z;
% On en déduit, par l'application de la fonction idoine, l'estimateur et
% l'intervalle de confiance pour \pi.
est_pi = 2 * a / l / est_nu;
var_est_pi = (2 * a / l / est_nu ^ 2) ^ 2 * var_est_nu;
% Affichage du résultat.
fprintf ('Au risque %.1e, \\pi est compris dans l''intervalle ', risque);
fprintf ('[%f, %f].\n', est_pi - z_risque * sqrt (var_est_pi), ...
  est_pi + z_risque * sqrt (var_est_pi));
% Fin de la fonction.
return
end
