%% Combinaison des informations issues du rejet et de la méthode de Buffon.
% Cette fonction calcule et affiche un intervalle de confiance pour \pi obtenu
% en combinant les estimateurs de Monte-Carlo obtenus par la méthode de Buffon
% elle-même et par l'exploitation des données de la méthode de rejet. Je ne
% commente que les points nouveaux par rapport à ce que nous avons déjà fait.
function KissCool ()
global a l risque z_risque
init_Buffon ();
Z = 1000000;
% Il y a deux variables aléatoires dont nous allons calculer l'espérance :
% l'habituelle \bar{n}, mais aussi le nombre de rejets avant d'arriver à simuler
% \theta, désigné par le suffixe 'g'. Notez que nous savons que ces variables
% sont indépendantes, de sorte que nous n'avons pas besoin de calculer leur
% corrélation en vue de les combiner, ce qui explique que nous ne calculions pas
% la somme des produits de ces deux variables. En outre, nous verrons plus loin
% qu'une autre astuce fait que nous n'avons pas besoin non plus de calculer la
% somme des g_i^2.
som_nb = 0;
som_nb2 = 0;
som_g = 0;
for i = 1 : Z
  % Cette fois-ci on utilise l'entièreté du retour de la fonction "sim_theta", y
  % compris donc le nombre d'essais infructueux, que nous stockons dans "g".
  [cossintheta, g] = sim_theta ();
  sintheta = cossintheta(2);
  nb = a / l * sintheta;
  som_nb = som_nb + nb;
  som_nb2 = som_nb2 + nb ^ 2;
  som_g = som_g + g;
end
% Nous calculons d'abord l'estimateur de \pi, ainsi que sa variance, obtenu à
% partir de la simulation des \bar{n}_i. Cet estimateur est désigné par le
% suffixe 'est1_pi'.
esp_nb_emp = som_nb / Z;
var_nb_emp = som_nb2 / Z - esp_nb_emp * esp_nb_emp;
est_nu = esp_nb_emp;
var_est_nu = var_nb_emp / Z;
est1_pi = 2 * a / l / est_nu;
var_est1_pi = (2 * a / l / est_nu ^ 2) ^ 2 * var_est_nu;
% On passe maintenant au calcul de l'estimateur de \pi utilisant les simulations
% de g.
esp_g_emp = som_g / Z;
% Comme g suit une loi géométrique, sa variance peut se déduire directement de
% son espérance. Notez que la variance déduite de l'espérance empirique n'est
% pas la même chose que la variance empirique elle-même ; mais dans tous les cas
% c'est un estimateur convergent de la vraie variance de g, et donc nous pouvons
% l'utiliser de la même façon.
var_g_emp = esp_g_emp * (esp_g_emp + 1);
% On déduit des résultats de simulation de g l'estimateur de E(g) (désignée par
% le suffixe 'Eg') et sa variance.
est_Eg = esp_g_emp;
var_est_Eg = var_g_emp / Z;
% On déduit de l'estimateur de g celui de \pi (et sa variance), désigné cette
% fois-ci par 'est2_pi'. Bien sûr, les formules sont différentes que pour passer
% de \nu à \pi, puisque la fonction effectuant la tranformation n'est pas la
% même.
est2_pi = 4 / (est_Eg + 1);
var_est2_pi = (4 / (est_Eg + 1) ^ 2) ^ 2 * var_est_Eg;
% À l'aide des formules trouvées à la question 20, on en déduit l'estimateur
% global de \pi, ainsi que sa variance.
est_pi = (est1_pi / var_est1_pi + est2_pi / var_est2_pi) / ...
  (1 / var_est1_pi + 1 / var_est2_pi);
var_est_pi = 1 / (1 / var_est1_pi + 1 / var_est2_pi);
fprintf ('Au risque %.1e, \\pi est compris dans l''intervalle ', risque);
fprintf ('[%f, %f].\n', est_pi - z_risque * sqrt (var_est_pi), ...
  est_pi + z_risque * sqrt (var_est_pi));
return
end
